import { 
  select, 
  csv,
	scalePoint,
  scaleLinear,
	max,
	axisBottom,
	axisLeft,
	format } from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const xValue = d => d.country;
  const yValue = d => d.immigrants_prop;
  const margin = {top: 70, right: 20, bottom: 40, left: 100};
  const circleRadius = 20;
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scalePoint()
  	.domain(data.map(xValue))
  	.range([0, innerWidth])
  	.padding(0.5);
  
  const yScale = scaleLinear()
  	.domain([0, max(data, d => d.immigrants_prop)])
  	.range([0, innerHeight].reverse());
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickFormat(format(".0%"))
  	.tickSize(-innerWidth);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll('.domain').remove();
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG
    .append('text')
      .text('Percentage')
      .attr('class', 'y-label')
      .attr('x', -innerHeight / 2)
      .attr('text-anchor', 'middle')
      .attr('y', -60);
  
  g.selectAll('circle').data(data).enter()
    .append('circle')
      .attr('cx', d => xScale(xValue(d)))
      .attr('cy', d => yScale(yValue(d)))
      .attr('r', circleRadius)
      .attr('rx', d => innerHeight - yScale(yValue(d)));
  
  // d => xScale.bandwidth()
  
  g.append('text')
  	.text('Percentange of foreign-born population')
  	.attr('y', -30)
  	.attr('class', 'title');
}

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.immigrants_prop = +d.immigrants_prop / 100;
  })
	render(data)
});






















